==> billogram-foundation-3.11.0.tgz: package/modules/components/monthpicker/Monthpicker.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import moment from 'moment';

import * as lang from '../../utils/lang';
import toTimestamp from '../../utils/toTimestamp';


export default ({
    block,
    displayName
} = {}) => {

    // These are extracted for for better testability because I prefer to select based on
    // display name instead of CSS class.
    const MonthpickerNextMonth = ({ onClick }) =>
        (<i className={ block('selector-icon', ['next', 'touchable']) } onClick={ onClick } />);

    MonthpickerNextMonth.propTypes = { onClick: PropTypes.func };

    const MonthpickerPreviousMonth = ({ onClick }) =>
        (<i className={ block('selector-icon', ['previous', 'touchable']) } onClick={ onClick } />);

    MonthpickerPreviousMonth.propTypes = { onClick: PropTypes.func };

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            onChange: PropTypes.func,
            ui: PropTypes.oneOf(['normal', 'extended']),
            yearOffset: PropTypes.number,
            value: PropTypes.number
        },

        getDefaultProps() {
            return {
                onChange: () => {},
                ui: 'normal',
                value: null,
                yearOffset: 0
            };
        },

        onNextMonth() {
            const { onChange, value } = this.props;
            onChange(toTimestamp(moment(value).add(1, 'months')));
        },

        onPreviousMonth() {
            const { onChange, value } = this.props;
            onChange(toTimestamp(moment(value).subtract(1, 'months')));
        },

        renderContent() {
            const { value, yearOffset } = this.props;
            const date = moment(value);

            switch (true) {
                case yearOffset === 0:
                    return (
                        <span>{ lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() }</span>
                    );

                case yearOffset < 0:
                    return (
                        <span>{ lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() - 1 } { lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() }</span>
                    );

                case yearOffset > 0:
                    return (
                        <span>{ lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() } { lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() + 1 }</span>
                    );
            }
        },

        render() {
            const { ui } = this.props;
            return (
                <div className={ block() }>
                    <MonthpickerPreviousMonth
                        onClick={ this.onPreviousMonth } />
                    <div className={ block('selector-text', { ui }) }>
                        { this.renderContent() }
                    </div>
                    <MonthpickerNextMonth
                        onClick={ this.onNextMonth } />
                </div>
            );
        }

    });

};

==> billogram-foundation-3.12.0.tgz: package/modules/components/monthpicker/Monthpicker.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import moment from 'moment';

import * as lang from '../../utils/lang';
import toTimestamp from '../../utils/toTimestamp';


export default ({
    block,
    displayName
} = {}) => {

    // These are extracted for better testability because I prefer to select based on
    // display name instead of CSS class.
    const NextMonth = React.createClass({

        displayName: `${displayName}NextMonth`,

        propTypes: {
            onClick: PropTypes.func.isRequired
        },

        render() {
            return (
                <i className={ block('selector-icon', ['next', 'touchable']) } onClick={ this.props.onClick } />
            );
        }

    });

    const PreviousMonth = React.createClass({

        displayName: `${displayName}PreviousMonth`,

        propTypes: {
            onClick: PropTypes.func.isRequired
        },

        render() {
            return (
                <i className={ block('selector-icon', ['previous', 'touchable']) } onClick={ this.props.onClick } />
            );
        }

    });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            onChange: PropTypes.func,
            ui: PropTypes.oneOf(['normal', 'extended']),
            yearOffset: PropTypes.number,
            value: PropTypes.number
        },

        getDefaultProps() {
            return {
                onChange: () => {},
                ui: 'normal',
                value: null,
                yearOffset: 0
            };
        },

        onNextMonth() {
            const { onChange, value } = this.props;
            onChange(toTimestamp(moment(value).add(1, 'months')));
        },

        onPreviousMonth() {
            const { onChange, value } = this.props;
            onChange(toTimestamp(moment(value).subtract(1, 'months')));
        },

        renderContent() {
            const { value, yearOffset } = this.props;
            const date = moment(value);

            switch (true) {
                case yearOffset === 0:
                    return (
                        <span>{ lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() }</span>
                    );

                case yearOffset < 0:
                    return (
                        <span>{ lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() - 1 } { lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() }</span>
                    );

                case yearOffset > 0:
                    return (
                        <span>{ lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() } { lang.pgettext('foundation-monthpicker', `Month--${date.month() + 1}`) } { date.year() + 1 }</span>
                    );
            }
        },

        render() {
            const { ui } = this.props;
            return (
                <div className={ block() }>
                    <PreviousMonth
                        onClick={ this.onPreviousMonth } />
                    <div className={ block('selector-text', { ui }) }>
                        { this.renderContent() }
                    </div>
                    <NextMonth
                        onClick={ this.onNextMonth } />
                </div>
            );
        }

    });

};
